/* This file is auto generated, version 1 */
/* SMP */
#define UTS_MACHINE "x86_64"
#define UTS_VERSION "#1 SMP Sun Feb 10 06:20:36 UTC 2008"
#define LINUX_COMPILE_TIME "06:20:36"
#define LINUX_COMPILE_BY "debuild"
#define LINUX_COMPILE_HOST "debuild"
#define LINUX_COMPILE_DOMAIN "mit.edu"
#define LINUX_COMPILER "gcc version 4.1.2 20061115 (prerelease) (Debian 4.1.1-21)"
